E2eOrder class

A validated E2E order decoded from bead metadata.

Constructors

E2eOrder(E2eSessionRequest request)
Creates an order around its reusable request.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
request E2eSessionRequest
Reusable typed session request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBead(Bead bead) E2eOrder?
Decodes an order, failing closed on missing or invalid values.