HarnessProcess class

The observable surface of a launched harness process.

Constructors

HarnessProcess({required Stream<String> diagnostics, required Future<int> exitCode, required Future<void> kill()})
Creates a process observation surface.
const

Properties

diagnostics Stream<String>
Stderr lines, where the harness publishes KEY=value diagnostics.
final
exitCode Future<int>
Completes when the harness exits.
final
hashCode int
The hash code for this object.
no setterinherited
kill Future<void> Function()
Idempotently terminates the harness process group.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited